import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

import { dropdownMenu } from "./dropdownMenu"

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Satellites Launches Per Year';
  
  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.count;
  const circleRadius = 6;
  const yAxisLabel = 'Count';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain([new Date("1974"), new Date("2019")])
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain([0, 350])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
    .curve(curveBasis)
  
    g.append('path')
        .attr('class', 'line-path')
        .attr('d', lineGenerator(data));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('data.json')
  .then(data => {
  	var formatted = [];
  	for(var x = 1973; x < 2019; x++) {
        formatted[x] = { "year": new Date(x + ""), "count": 0 };
    }
    data.forEach(d => {
      var country = d["Country of Operator/Owner"];
      var date = new Date(d["Date of Launch"]);
      var year = date.getFullYear();
      formatted[year].count = formatted[year].count + 1;
    });
  
  var results = [];
  for(var x = 0; x < formatted.length; x++) {
    if (formatted[x]) {
      results.push(formatted[x]);
    }
  }
  render(results);
});